==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/runtime/RawExtensionBuilder.java <==
package io.fabric8.openshift.api.model.runtime;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RawExtensionBuilder extends io.fabric8.openshift.api.model.runtime.RawExtensionFluentImpl<io.fabric8.openshift.api.model.runtime.RawExtensionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.runtime.RawExtension,io.fabric8.openshift.api.model.runtime.RawExtensionBuilder>{
  public RawExtensionBuilder() {
    this(false);
  }
  public RawExtensionBuilder(java.lang.Boolean validationEnabled) {
    this(new RawExtension(), validationEnabled);
  }
  public RawExtensionBuilder(io.fabric8.openshift.api.model.runtime.RawExtensionFluent<?> fluent) {
    this(fluent, false);
  }
  public RawExtensionBuilder(io.fabric8.openshift.api.model.runtime.RawExtensionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RawExtension(), validationEnabled);
  }
  public RawExtensionBuilder(io.fabric8.openshift.api.model.runtime.RawExtensionFluent<?> fluent,io.fabric8.openshift.api.model.runtime.RawExtension instance) {
    this(fluent, instance, false);
  }
  public RawExtensionBuilder(io.fabric8.openshift.api.model.runtime.RawExtensionFluent<?> fluent,io.fabric8.openshift.api.model.runtime.RawExtension instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    this.validationEnabled = validationEnabled; 
  }
  public RawExtensionBuilder(io.fabric8.openshift.api.model.runtime.RawExtension instance) {
    this(instance,false);
  }
  public RawExtensionBuilder(io.fabric8.openshift.api.model.runtime.RawExtension instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.runtime.RawExtensionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.runtime.RawExtension build() {
    RawExtension buildable = new RawExtension();
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RawExtensionBuilder that = (RawExtensionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/runtime/RawExtensionBuilder.java <==
package io.fabric8.openshift.api.model.runtime;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RawExtensionBuilder extends io.fabric8.openshift.api.model.runtime.RawExtensionFluentImpl<io.fabric8.openshift.api.model.runtime.RawExtensionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.runtime.RawExtension,io.fabric8.openshift.api.model.runtime.RawExtensionBuilder>{
  public RawExtensionBuilder() {
    this(false);
  }
  public RawExtensionBuilder(java.lang.Boolean validationEnabled) {
    this(new RawExtension(), validationEnabled);
  }
  public RawExtensionBuilder(io.fabric8.openshift.api.model.runtime.RawExtensionFluent<?> fluent) {
    this(fluent, false);
  }
  public RawExtensionBuilder(io.fabric8.openshift.api.model.runtime.RawExtensionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RawExtension(), validationEnabled);
  }
  public RawExtensionBuilder(io.fabric8.openshift.api.model.runtime.RawExtensionFluent<?> fluent,io.fabric8.openshift.api.model.runtime.RawExtension instance) {
    this(fluent, instance, false);
  }
  public RawExtensionBuilder(io.fabric8.openshift.api.model.runtime.RawExtensionFluent<?> fluent,io.fabric8.openshift.api.model.runtime.RawExtension instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RawExtensionBuilder(io.fabric8.openshift.api.model.runtime.RawExtension instance) {
    this(instance,false);
  }
  public RawExtensionBuilder(io.fabric8.openshift.api.model.runtime.RawExtension instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.runtime.RawExtensionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.runtime.RawExtension build() {
    RawExtension buildable = new RawExtension();
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RawExtensionBuilder that = (RawExtensionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
